@@ -9,7 +9,7 @@ from datacite import schema40, schema43
 from caltechdata_api import decustomize_schema
 
 
-def get_metadata(idv, production=True, auth=None, emails=False, schema="40"):
+def get_metadata(idv, production=True, validate=True, emails=False, schema="40"):
     # Returns just DataCite metadata or DataCite metadata with emails
 
     if production == True:
@@ -17,7 +17,7 @@ def get_metadata(idv, production=True, auth=None, emails=False, schema="40"):
     else:
         api_url = "https://cd-sandbox.tind.io/api/record/"
 
-    r = requests.get(api_url + str(idv))  # ,auth=auth)
+    r = requests.get(api_url + str(idv))
     r_data = r.json()
     if "message" in r_data:
         raise AssertionError(
@@ -36,22 +36,23 @@ def get_metadata(idv, production=True, auth=None, emails=False, schema="40"):
         metadata = decustomize_schema(metadata, pass_emails=True, schema=schema)
     else:
         metadata = decustomize_schema(metadata, schema=schema)
-        if schema == "40":
-            try:
-                assert schema40.validate(metadata)
-            except AssertionError:
-                v = schema40.validator.validate(metadata)
-                errors = sorted(v.iter_errors(instance), key=lambda e: e.path)
-                for error in errors:
-                    print(error.message)
-        if schema == "43":
-            try:
-                assert schema43.validate(metadata)
-            except AssertionError:
-                v = schema43.validator.validate(metadata)
-                errors = sorted(v.iter_errors(instance), key=lambda e: e.path)
-                for error in errors:
-                    print(error.message)
+        if validate:
+            if schema == "40":
+                try:
+                    assert schema40.validate(metadata)
+                except AssertionError:
+                    v = schema40.validator.validate(metadata)
+                    errors = sorted(v.iter_errors(instance), key=lambda e: e.path)
+                    for error in errors:
+                        print(error.message)
+            if schema == "43":
+                try:
+                    assert schema43.validate(metadata)
+                except AssertionError:
+                    v = schema43.validator.validate(metadata)
+                    errors = sorted(v.iter_errors(instance), key=lambda e: e.path)
+                    for error in errors:
+                        print(error.message)
 
     return metadata
 
@@ -71,8 +72,12 @@ if __name__ == "__main__":
     parser.add_argument("-emails", dest="emails", action="store_true")
     parser.add_argument("-test", dest="production", action="store_false")
     parser.add_argument("-xml", dest="save_xml", action="store_true")
-    parser.add_argument("-auth_user", help="Username for basic authentication")
-    parser.add_argument("-auth_pass", help="Password for basic authentication")
+    parser.add_argument(
+        "-skip_validate",
+        dest="skip_validate",
+        action="store_true",
+        help="skip validation of metadata",
+    )
     parser.add_argument("-schema", default="40", help="Schema Version")
 
     args = parser.parse_args()
@@ -80,12 +85,14 @@ if __name__ == "__main__":
     production = args.production
     emails = args.emails
     schema = args.schema
-    auth = None
-    if args.auth_user != None:
-        auth = (args.auth_user, args.auth_pass)
+    skip_validate = args.skip_validate
+    if skip_validate:
+        validate = False
+    else:
+        validate = True
 
     for idv in args.ids:
-        metadata = get_metadata(idv, production, auth, emails, schema)
+        metadata = get_metadata(idv, production, validate, emails, schema)
         outfile = open(str(idv) + ".json", "w")
         outfile.write(json.dumps(metadata))
         outfile.close()
